@@ -16,7 +16,7 @@ DEFAULT_IMPORTS_FORBIDDEN_FROM = {
 def pytest_configure(config):
     config.addinivalue_line(
         'markers',
-        "import-check: Test to check violation of forbidden imports")
+        f"{PLUGIN_NAME}: Test to check violation of forbidden imports")
 
 
 def pytest_addoption(parser):
@@ -74,7 +74,9 @@ class ImportCheckItem(pytest.Item):
     def __init__(self, name, parent, import_statement):
         super().__init__(name, parent)
         self.add_marker(PLUGIN_NAME)
+
         self._import_statement = import_statement
+        self._nodeid += f"::{PLUGIN_NAME}"
 
     def runtest(self):
         violating_imports = []
