@@ -15,7 +15,7 @@ DEFAULT_INIT_FORBIDDEN_IN = {
 def pytest_configure(config):
     config.addinivalue_line(
         'markers',
-        "init-check: Test to check forbidden __init__.py placement")
+        f"{PLUGIN_NAME}: Test to check forbidden __init__.py placement")
 
 
 def pytest_addoption(parser):
@@ -71,6 +71,7 @@ class InitCheckItem(pytest.Item):
 
         self._basename = basename
         self._filename = filename
+        self._nodeid += f"::{PLUGIN_NAME}"
 
     def runtest(self):
         if self._filename == INIT_FILENAME:
