@@ -15,7 +15,7 @@ DEFAULT_REQUIRED_NEWLINE_IN = {
 def pytest_configure(config):
     config.addinivalue_line(
         'markers',
-        "newline-check: Test to check whether newline exists at the end of certain files")
+        f"{PLUGIN_NAME}: Test to check whether newline exists at the end of certain files")
 
 
 def pytest_addoption(parser):
@@ -63,6 +63,8 @@ class NewlineCheckItem(pytest.Item):
         super().__init__(name, parent)
         self.add_marker(PLUGIN_NAME)
 
+        self._nodeid += f"::{PLUGIN_NAME}"
+
     def collect(self):
         return self
 
